A small package for converting text to ascii, or just basic maths.

Usage:

```
import poggers  
text = 'Hello world'  
binary = poggers.Binary(text)  
print(binary)
```

The following options include:


Maths:
```
poggers.Add(x, y)
poggers.Minus(x, y)
poggers.Times(x, y)
poggers.Divide(x, y)
```

Ascii Text:
```
poggers.Binary(text)
poggers.Banner(text)
poggers.Morse(text)
poggers.Block(text)
poggers.Chunky(text)
poggers.Cosmic(text)
poggers.Diamond(text)
poggers.Isometric(text)
poggers.Italics(text)
poggers.Roman(text)
poggers.Shadow(text)
poggers.Slant(text)
poggers.Speed(text)

```

